@@ -17,9 +17,10 @@ You may use short names instead of poor long names.
 
 """
 
-__version_info__ = ('1', '0', '0')
+__version_info__ = ('1', '0', '4')
 __version__ = '.'.join(__version_info__)
 
 from .binary_size_formatter import BinarySizeFormatter
-from .subpr import SubProcess
+from .subpr import SubProcess, SubProcessStdoutReceiver
 import zobepy.dump
+import zobepy.util
